==> haskell-cheapskate-0.1.0.5-43-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cheapskate
version: 0.1.0.5
id: cheapskate-0.1.0.5-LIScDOE1wLOEJvj1j7EjJG
key: cheapskate-0.1.0.5-LIScDOE1wLOEJvj1j7EjJG
license: BSD3
copyright: (C) 2012-2013 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: http://github.com/jgm/cheapskate
synopsis: Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.
    .
    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.
category: Text
author: John MacFarlane
exposed: True
exposed-modules:
    Cheapskate Cheapskate.Parse Cheapskate.Types Cheapskate.Html
hidden-modules: Cheapskate.Util Cheapskate.Inlines
                Cheapskate.ParserCombinators Paths_cheapskate
abi: c9ef90aec3ad91b9ccf6fac58fe57d6d
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cheapskate-0.1.0.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/cheapskate-0.1.0.5
data-dir: /usr/share/i386-linux-ghc-8.0.1/cheapskate-0.1.0.5
hs-libraries: HScheapskate-0.1.0.5-LIScDOE1wLOEJvj1j7EjJG
depends:
    base-4.9.0.0 blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    containers-0.5.7.1 data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM syb-0.6-C65vWCsht6A8uLstpQIXyj
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    uniplate-1.6.12-3VwHJoF30p3s45WrrHev
    xss-sanitize-0.3.5.7-CknHRcaYThkr8Cwd0gpZ4
haddock-interfaces: /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html: /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cheapskate-0.1.0.5-48-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cheapskate
version: 0.1.0.5
id: cheapskate-0.1.0.5-7CsxfAwa6MX2bNhNTA74NF
key: cheapskate-0.1.0.5-7CsxfAwa6MX2bNhNTA74NF
license: BSD3
copyright: (C) 2012-2013 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: http://github.com/jgm/cheapskate
synopsis: Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.
    .
    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.
category: Text
author: John MacFarlane
exposed: True
exposed-modules:
    Cheapskate Cheapskate.Parse Cheapskate.Types Cheapskate.Html
hidden-modules: Cheapskate.Util Cheapskate.Inlines
                Cheapskate.ParserCombinators Paths_cheapskate
abi: 4fc047789c362acabad9739b121798a6
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cheapskate-0.1.0.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/cheapskate-0.1.0.5
data-dir: /usr/share/i386-linux-ghc-8.0.1/cheapskate-0.1.0.5
hs-libraries: HScheapskate-0.1.0.5-7CsxfAwa6MX2bNhNTA74NF
depends:
    base-4.9.0.0 blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    containers-0.5.7.1 data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM syb-0.6-C65vWCsht6A8uLstpQIXyj
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    uniplate-1.6.12-GeJZUKnYhe2EvTBj9Ni0S0
    xss-sanitize-0.3.5.7-52sK2IstXftHMu6Gfxxz0d
haddock-interfaces: /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html: /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
